pub enum Source {
Table {
name: Slice,
alias: StrRef,
columns: Slice,
},
Subquery {
query: QueryRef,
alias: StrRef,
columns: Slice,
},
Join {
left: SourceRef,
right: SourceRef,
kind: JoinKind,
natural: bool,
on: ExprRef,
using: Slice,
},
}Expand description
One entry in a FROM clause, which is a tree because joins nest.
Variants
Table
A named table, possibly qualified by schema and catalog.
Fields
Subquery
A parenthesised query in the FROM clause.
Fields
Join
Two sources joined.