pub struct DropTable {
pub names: Slice,
pub if_exists: bool,
}Expand description
DROP TABLE a, b.
Fields
names: SliceThe names, as a run of Slice into Ast::name_lists, each of which is a run of parts.
if_exists: boolWhether IF EXISTS was written.